@@ -430,7 +430,7 @@ class API extends Handler {
 			}
 
 			array_push($rv, array(
-				"id" => (int)$line['id'],
+				"id" => (int)label_to_feed_id($line['id']),
 				"caption" => $line['caption'],
 				"fg_color" => $line['fg_color'],
 				"bg_color" => $line['bg_color'],
@@ -669,7 +669,7 @@ class API extends Handler {
 					$headline_row['attachments'] = get_article_enclosures(
 						$line['id']);
 
-				if (!$show_excerpt)
+				if ($show_excerpt)
 					$headline_row["excerpt"] = $line["content_preview"];
 
 				if ($show_content) {
@@ -678,7 +678,7 @@ class API extends Handler {
 						$headline_row["content"] = sanitize(
 							$line["content"],
 							sql_bool_to_bool($line['hide_images']),
-							false, $line["site_url"]);
+							false, $line["site_url"], false, $line["id"]);
 					} else {
 						$headline_row["content"] = $line["content"];
 					}
