@@ -42,7 +42,11 @@ class FeedItem_Atom extends FeedItem_Common {
 					|| $link->getAttribute("rel") == "standout")) {
 				$base = $this->xpath->evaluate("string(ancestor-or-self::*[@xml:base][1]/@xml:base)", $link);
 
-				return rewrite_relative_url($base, $link->getAttribute("href"));
+				if ($base)
+					return rewrite_relative_url($base, $link->getAttribute("href"));
+				else
+					return $link->getAttribute("href");
+
 			}
 		}
 	}
@@ -133,7 +137,7 @@ class FeedItem_Atom extends FeedItem_Common {
 			}
 		}
 
-		$enclosures = $this->xpath->query("media:content", $this->elem);
+		$enclosures = $this->xpath->query("media:content | media:group/media:content", $this->elem);
 
 		foreach ($enclosures as $enclosure) {
 			$enc = new FeedEnclosure();
@@ -142,6 +146,9 @@ class FeedItem_Atom extends FeedItem_Common {
 			$enc->link = $enclosure->getAttribute("url");
 			$enc->length = $enclosure->getAttribute("length");
 
+			$desc = $this->xpath->query("media:description", $enclosure)->item(0);
+			if ($desc) $enc->title = strip_tags($desc->nodeValue);
+
 			array_push($encs, $enc);
 		}
 
