@@ -255,6 +255,7 @@ class Feeds extends Handler_Protected {
 		$last_error = $qfh_ret[3];
 		$last_updated = strpos($qfh_ret[4], '1970-') === FALSE ?
 			make_local_datetime($qfh_ret[4], false) : __("Never");
+		$highlight_words = $qfh_ret[5];
 
 		$vgroup_last_feed = $vgr_last_feed;
 
@@ -509,7 +510,7 @@ class Feeds extends Handler_Protected {
 						$tags = false;
 
 					$line["content"] = sanitize($line["content"],
-							sql_bool_to_bool($line['hide_images']), false, $entry_site_url);
+							sql_bool_to_bool($line['hide_images']), false, $entry_site_url, $highlight_words, $line["id"]);
 
 					foreach (PluginHost::getInstance()->get_hooks(PluginHost::HOOK_RENDER_ARTICLE_CDM) as $p) {
 						$line = $p->hook_render_article_cdm($line);
@@ -560,6 +561,13 @@ class Feeds extends Handler_Protected {
 
 					$reply['content'] .= "</div>";
 
+					if ($highlight_words && count($highlight_words > 0)) {
+						foreach ($highlight_words as $word) {
+							$line["title"] = preg_replace("/(\Q$word\E)/i",
+								"<span class=\"highlight\">$1</span>", $line["title"]);
+						}
+					}
+
 					$reply['content'] .= "<span id=\"RTITLE-$id\"
 						onclick=\"return cdmClicked(event, $id);\"
 						class=\"titleWrap $hlc_suffix\">
@@ -621,7 +629,9 @@ class Feeds extends Handler_Protected {
 					}
 					$reply['content'] .= "</div>";
 
-					$reply['content'] .= "<div class=\"cdmContentInner\">";
+					if (!$line['lang']) $line['lang'] = 'en';
+
+					$reply['content'] .= "<div class=\"cdmContentInner\" lang=\"".$line['lang']."\">";
 
 			if ($line["orig_feed_id"]) {
 
@@ -691,10 +701,13 @@ class Feeds extends Handler_Protected {
 						} else {
 							$comments_url = htmlspecialchars($line["link"]);
 						}
-						$entry_comments = "<a target='_blank' href=\"$comments_url\">$num_comments comments</a>";
+						$entry_comments = "<a class=\"postComments\"
+							target='_blank' href=\"$comments_url\">$num_comments ".
+							_ngettext("comment", "comments", $num_comments)."</a>";
+
 					} else {
 						if ($line["comments"] && $line["link"] != $line["comments"]) {
-							$entry_comments = "<a target='_blank' href=\"".htmlspecialchars($line["comments"])."\">comments</a>";
+							$entry_comments = "<a class=\"postComments\" target='_blank' href=\"".htmlspecialchars($line["comments"])."\">".__("comments")."</a>";
 						}
 					}
 
@@ -1134,7 +1147,7 @@ class Feeds extends Handler_Protected {
 
 		if (!SPHINX_ENABLED) {
 			print "<div style=\"float : left\">
-				<a class=\"visibleLink\" target=\"_blank\" href=\"http://tt-rss.org/wiki/SearchSyntax\">Search syntax</a>
+				<a class=\"visibleLink\" target=\"_blank\" href=\"http://tt-rss.org/wiki/SearchSyntax\">".__("Search syntax")."</a>
 				</div>";
 		}
 
