@@ -85,8 +85,9 @@ class Handler_Public extends Handler {
 			}
 
 			$tpl->setVariable('SELF_URL', htmlspecialchars(get_self_url_prefix()), true);
-			$line["content_preview"] = truncate_string(strip_tags($line["content_preview"]), 100, '...');
 			while ($line = $this->dbh->fetch_assoc($result)) {
+				$line["content_preview"] = truncate_string(strip_tags($line["content_preview"]), 100, '...');
+
 				foreach (PluginHost::getInstance()->get_hooks(PluginHost::HOOK_QUERY_HEADLINES) as $p) {
 					$line = $p->hook_query_headlines($line);
 				}
@@ -390,14 +391,18 @@ class Handler_Public extends Handler {
 		}
 	}
 
+	function updateTask() {
+		PluginHost::getInstance()->run_hooks(PluginHost::HOOK_UPDATE_TASK, "hook_update_task", $op);
+	}
+
+	function housekeepingTask() {
+		PluginHost::getInstance()->run_hooks(PluginHost::HOOK_HOUSE_KEEPING, "hook_house_keeping", $op);
+	}
+
 	function globalUpdateFeeds() {
-		include "rssfuncs.php";
-		// Update all feeds needing a update.
-		update_daemon_common(0, true, false);
-		housekeeping_common(false);
+		RPC::updaterandomfeed_real($this->dbh);
 
 		PluginHost::getInstance()->run_hooks(PluginHost::HOOK_UPDATE_TASK, "hook_update_task", $op);
-
 	}
 
 	function sharepopup() {
